Description Usage Arguments Examples
Compute accuracy by block (any number of categories)
1 |
data |
Data needs to be a list of data frames. Each data set needs columns labeled "block", "cat", & "resp" |
1 2 3 4 | # data needs to be a list of data frames
# each data set needs columns labeled "block", "cat", & "resp"
catAccuracy(cat2_data)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.