This package contains several small functions that perform simple tasks that are repeated often in analysis of categorization data (e.g., accuracy computations by block).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.