Description Usage Arguments Examples
Compute mean values for each level of a grouping variable (e.g., block)
1 |
data |
Data needs to be a list of data frames. Each data set needs columns labeled "block", "cat", & "resp" |
1 2 3 | # compute mean values for each level of a grouping variable (e.g., block)
meansByBlock(cat2_data)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.